@@ -14,7 +14,7 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION = '3.5';    # VERSION
+our $VERSION = '3.6';    # VERSION
 my @OPTIONS_ATTRIBUTES
     = qw/format short repeatable negativable autosplit doc/;
 
@@ -148,7 +148,7 @@ MooX::Options - add option keywords to your object (Mo/Moo/Moose)
 
 =head1 VERSION
 
-version 3.5
+version 3.6
 
 =head1 MooX::Options
 
@@ -454,12 +454,18 @@ To use namespace::clean you need to add 2 methods as an exception. It is use by
 
 If you are using Mouse, I'm sorry to say than the rewrite of this module has make it just incompatible. Mouse is not design to by compatible with anything else than Mouse itself. I could just suggest to use Moo instead, which is a great and compatible replacement.
 
+=head1 More examples
+
+L<http://perltalks.celogeek.com/slides/2012/08/moox-options-slide3d.html>
+
 =head1 THANKS
 
 =over
 
 =item Matt S. Trout (mst) <mst@shadowcat.co.uk> : For his patience and advice.
 
+=item Tomas Doran (t0m) <bobtfish@bobtfish.net> : To help me release the new version, and using it :)
+
 =back
 
 =head1 BUGS
